==> hsa-rocr-5.4.1-1-x86_64.pkg.tar.zst: opt/rocm/hsa/include/hsa/amd_hsa_common.h <==
/*
    Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
   */

#ifndef HSA_RUNTIME_WRAPPER_INC_AMD_HSA_COMMON_H
#define HSA_RUNTIME_WRAPPER_INC_AMD_HSA_COMMON_H 

#pragma message("amd_hsa_common.h has moved to /opt/rocm/include/hsa and package include paths have changed.\nInclude as \"hsa/amd_hsa_common.h\" when using cmake packages.")
#include "../../../include/hsa/amd_hsa_common.h"


#endif

==> hsa-rocr-5.7.1-1-x86_64.pkg.tar.zst: opt/rocm/hsa/include/hsa/amd_hsa_common.h <==
/*
    Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
   THE SOFTWARE.
   */

#ifndef HSA_RUNTIME_WRAPPER_INC_AMD_HSA_COMMON_H
#define HSA_RUNTIME_WRAPPER_INC_AMD_HSA_COMMON_H

#ifndef ROCM_HEADER_WRAPPER_WERROR
#define ROCM_HEADER_WRAPPER_WERROR 0
#endif
#if ROCM_HEADER_WRAPPER_WERROR  /* ROCM_HEADER_WRAPPER_WERROR 1 */
#error "amd_hsa_common.h has moved to /opt/rocm/include/hsa and package include paths have changed.\nInclude as \"hsa/amd_hsa_common.h\" when using cmake packages."
#else  /* ROCM_HEADER_WRAPPER_WERROR 0 */
#if defined(__GNUC__)
#warning "amd_hsa_common.h has moved to /opt/rocm/include/hsa and package include paths have changed.\nInclude as \"hsa/amd_hsa_common.h\" when using cmake packages."
#else
#pragma message("amd_hsa_common.h has moved to /opt/rocm/include/hsa and package include paths have changed.\nInclude as \"hsa/amd_hsa_common.h\" when using cmake packages.")
#endif
#endif  /* ROCM_HEADER_WRAPPER_WERROR */
#include "../../../include/hsa/amd_hsa_common.h"


#endif
